Enum stream_httparse::Method [−][src]
pub enum Method {
OPTIONS,
GET,
HEAD,
POST,
PUT,
DELETE,
TRACE,
CONNECT,
}Expand description
The different HTTP-Methods as defined by RFC 2616 5.1.1
Variants
OPTIONS
Requests the Communication-Options available for a given Ressource
GET
Retrieves the specified Ressource from the Server
HEAD
Identical to the GET-Method, but the Server is not required to return a Response-Body
POST
Used to post Data to the Server
PUT
Tells the Server to store the supplied Body under a given Ressource URI
DELETE
Requests that the given Data assosicated with the Ressource-URI is deleted
TRACE
Used to invoke a remote application-layer loopback
CONNECT
Reserved
Implementations
Serializes the header into a WASM friendly form
Deserializes the Output from the wasm_serialize method
back into a valid Method