pub struct Request<'a> { /* fields omitted */ }
Represents a single HTTP-Request
Creates a new Request with the given Data as its
initial Data
Serializes the Request and returns the final Data
as a tuple of (HTTP-Head, HTTP-Body)
Returns the Protocol of the Request
Returns the Method of the Request
Returns the Path of the Request
Returns the Headers of the Request
Returns a mutable Reference to the Headers of the Request
Returns the Body of the Request
Checks if the Requests expects a
Keep-alive connection
Overwrites the Path with the new Path
Overwrites the Path with the new Path, but using
an owned String instead of a reference
Replaces the current Body with the given Data
Formats the value using the given formatter. Read more
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
Converts the given value to a String. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.